@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2015-2022 The plumed team
+   Copyright (c) 2015-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -139,6 +139,13 @@ boundaries. Note that:
 - If in the region outside the limit boundary the system has a free energy minimum, the INTERVAL keyword should
   be used together with a \ref UPPER_WALLS or \ref LOWER_WALLS at boundary.
 
+For systems with multiple CVs that share identical properties, PBMetaD with partitioned families can be used
+to group them under one bias potential that each contributes to \cite Prakash2018PF. This is done with a list
+of PF keywords, where each PF* argument contains the list of CVs from ARG to be placed in that family. Once
+invoked, each CV in ARG must be placed in exactly one PF, even if it results in families containing only one CV.
+Additionally, in cases where each of SIGMA or GRID entry would correspond to each ARG entry, they now correspond to
+each PF and must be adjusted accordingly.
+
 Multiple walkers  \cite multiplewalkers can also be used. See below the examples.
 
 \par Examples
@@ -169,6 +176,23 @@ FILE=HILLS_d1,HILLS_d2
 PRINT ARG=d1,d2,pb.bias STRIDE=100 FILE=COLVAR
 \endplumedfile
 
+\par
+Using partitioned families, each CV in ARG must be in exactly one family. Here,
+the distance between atoms 1,2 is degenerate with 2,4, but not with the
+distance between 3,5. Note that two SIGMA are provided to match the two PF.
+\plumedfile
+DISTANCE ATOMS=3,5 LABEL=d1
+DISTANCE ATOMS=2,4 LABEL=d2
+DISTANCE ATOMS=1,2 LABEL=d3
+PBMETAD ...
+ARG=d1,d2,d3 SIGMA=0.2,0.2 HEIGHT=0.3
+PF0=d1 PF1=d2,d3
+PACE=500 BIASFACTOR=8 LABEL=pb
+FILE=HILLS_d1,HILLS_d2
+... PBMETAD
+PRINT ARG=d1,d2,d3,pb.bias STRIDE=100 FILE=COLVAR
+\endplumedfile
+
 \par
 The following input enables the MPI version of multiple-walkers.
 \plumedfile
@@ -253,6 +277,11 @@ private:
   std::vector<std::unique_ptr<GridBase>> BiasGrids_;
   std::vector<std::unique_ptr<OFile>> gridfiles_;
   int wgridstride_;
+  // Partitioned Families
+  unsigned int pf_n_; // initialize number of partitioned families
+  std::vector<int> pfs_; //std::vector length of arguments that holds which pf# each cv belongs in
+  std::vector<Value*> pfhold_; // std::vector length of pf_n which stores a pointer to the first argument fed to each family
+  bool do_pf_; // if partitioned families are enabled
   // multiple walkers
   int mw_n_;
   std::string mw_dir_;
@@ -312,7 +341,7 @@ void PBMetaD::registerKeywords(Keywords& keys) {
   keys.add("optional","FMT","specify format for HILLS files (useful for decrease the number of digits in regtests)");
   keys.add("optional","BIASFACTOR","use well tempered metadynamics with this bias factor, one for all biases.  Please note you must also specify temp");
   keys.add("optional","TEMP","the system temperature - this is only needed if you are doing well-tempered metadynamics");
-  keys.add("optional","TAU","in well tempered metadynamics, sets height to (\\f$k_B \\Delta T\\f$*pace*timestep)/tau");
+  keys.add("optional","TAU","in well tempered metadynamics, sets height to (k_B Delta T*pace*timestep)/tau");
   keys.add("optional","GRID_MIN","the lower bounds for the grid");
   keys.add("optional","GRID_MAX","the upper bounds for the grid");
   keys.add("optional","GRID_BIN","the number of bins for the grid");
@@ -325,6 +354,7 @@ void PBMetaD::registerKeywords(Keywords& keys) {
   keys.add("optional","ADAPTIVE","use a geometric (=GEOM) or diffusion (=DIFF) based hills width scheme. Sigma is one number that has distance units or timestep dimensions");
   keys.add("optional","SIGMA_MAX","the upper bounds for the sigmas (in CV units) when using adaptive hills. Negative number means no bounds ");
   keys.add("optional","SIGMA_MIN","the lower bounds for the sigmas (in CV units) when using adaptive hills. Negative number means no bounds ");
+  keys.add("numbered","PF", "specify which CVs belong in a partitioned family. Once a PF is specified, all CVs in ARG must be placed in a PF even if there is one CV per PF”");
   keys.add("optional","SELECTOR", "add forces and do update based on the value of SELECTOR");
   keys.add("optional","SELECTOR_ID", "value of SELECTOR");
   keys.add("optional","WALKERS_ID", "walker id");
@@ -350,10 +380,12 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   adaptive_(FlexibleBin::none),
   grid_(false),
   wgridstride_(0),
+  pf_n_(0), do_pf_(false),
   mw_n_(1), mw_dir_(""), mw_id_(0), mw_rstride_(1),
   walkers_mpi_(false), mpi_nw_(0),
   do_select_(false)
 {
+
   // parse the flexible hills
   std::string adaptiveoption;
   adaptiveoption="NONE";
@@ -372,11 +404,63 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
 
   parse("FMT",fmt_);
 
+  // Partitioned Families - fill with -1 to mark as invalid
+  pfs_.assign(getNumberOfArguments(), -1);
+  pfhold_.resize(getNumberOfArguments());
+  std::vector<Value*> familyargs;
+  for(int i = 0;; i++) {
+    parseArgumentList("PF", i, familyargs);
+    if (familyargs.empty()) break;
+
+    do_pf_ = true;
+    log << "  Identified Partitioned Family " << i << ":";
+    for (unsigned j = 0; j < familyargs.size(); j++) {
+      log << " " << familyargs[j]->getName();
+      // loop through the argument list to make sure it exists and assign it
+      bool foundArg = false;
+      for (unsigned argnum = 0; argnum < getNumberOfArguments(); argnum++) {
+        if (familyargs[j]->getName() == getPntrToArgument(argnum)->getName()) {
+          foundArg = true;
+          if (pfs_[argnum] != -1) {
+            error(familyargs[j]->getName() + " already present in PF" + std::to_string(pfs_[argnum]));
+          }
+          pfs_[argnum] = i;  // store the pf# for each cv
+          if (pfhold_[i] == nullptr) {
+            // if this is the first argument in the family, store a pointer for it (this is for HILLS & GRID files)
+            pfhold_[i] = getPntrToArgument(argnum);
+          }
+        }
+      }
+      if (!foundArg) {
+        error(familyargs[j]->getName() + " in PF" + std::to_string(i) + " not found in ARG");
+      }
+    }
+    log << "\n";
+    pf_n_++;
+  }
+
+  // if PF were specified, every argument gets treated as its own PF
+  if (!do_pf_) {
+    pf_n_ = getNumberOfArguments();
+    for(unsigned i=0; i < pf_n_; i++) {
+      pfhold_[i] = getPntrToArgument(i);
+      pfs_[i] = i;
+    }
+  } else {
+    // If we are doing PF, make sure each argument got assigned to a family.
+    for (unsigned i = 0; i < getNumberOfArguments(); i++) {
+      if (pfs_[i] == -1) error(getPntrToArgument(i)->getName() + " was not assigned a PF");
+    }
+  }
+
   // parse the sigma
   parseVector("SIGMA",sigma0_);
   if(adaptive_==FlexibleBin::none) {
     // if you use normal sigma you need one sigma per argument
-    if( sigma0_.size()!=getNumberOfArguments() ) error("number of arguments does not match number of SIGMA parameters");
+    if( sigma0_.size()!=pf_n_ ) {
+      std::string fields = do_pf_ ? "PFs" : "arguments";
+      error("number of " + fields + " does not match number of SIGMA parameters");
+    }
   } else {
     // if you use flexible hills you need one sigma
     if(sigma0_.size()!=1) {
@@ -390,22 +474,22 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
     }
     // here evtl parse the sigma min and max values
     parseVector("SIGMA_MIN",sigma0min_);
-    if(sigma0min_.size()>0 && sigma0min_.size()!=getNumberOfArguments()) {
-      error("the number of SIGMA_MIN values be the same of the number of the arguments");
+    if(sigma0min_.size()>0 && sigma0min_.size()!=pf_n_) {
+      error("the number of SIGMA_MIN values be the same of the number of the arguments/PF");
     } else if(sigma0min_.size()==0) {
-      sigma0min_.resize(getNumberOfArguments());
-      for(unsigned i=0; i<getNumberOfArguments(); i++) {sigma0min_[i]=-1.;}
+      sigma0min_.resize(pf_n_);
+      for(unsigned i=0; i<pf_n_; i++) {sigma0min_[i]=-1.;}
     }
 
     parseVector("SIGMA_MAX",sigma0max_);
-    if(sigma0max_.size()>0 && sigma0max_.size()!=getNumberOfArguments()) {
-      error("the number of SIGMA_MAX values be the same of the number of the arguments");
+    if(sigma0max_.size()>0 && sigma0max_.size()!=pf_n_) {
+      error("the number of SIGMA_MAX values be the same of the number of the arguments/PF");
     } else if(sigma0max_.size()==0) {
-      sigma0max_.resize(getNumberOfArguments());
-      for(unsigned i=0; i<getNumberOfArguments(); i++) {sigma0max_[i]=-1.;}
+      sigma0max_.resize(pf_n_);
+      for(unsigned i=0; i<pf_n_; i++) {sigma0max_[i]=-1.;}
     }
 
-    for(unsigned i=0; i<getNumberOfArguments(); i++) {
+    for(unsigned i=0; i<pf_n_; i++) {
       std::vector<double> tmp_smin, tmp_smax;
       tmp_smin.resize(1,sigma0min_[i]);
       tmp_smax.resize(1,sigma0max_[i]);
@@ -418,11 +502,15 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   parse("PACE",stride_);
   if(stride_<=0) error("frequency for hill addition is nonsensical");
 
+
   parseVector("FILE",hillsfname_);
   if(hillsfname_.size()==0) {
-    for(unsigned i=0; i<getNumberOfArguments(); i++) hillsfname_.push_back("HILLS."+getPntrToArgument(i)->getName());
+    for(unsigned i=0; i< pf_n_; i++) {
+      std::string name = do_pf_ ? "HILLS.PF"+std::to_string(i) : "HILLS."+getPntrToArgument(i)->getName();
+      hillsfname_.push_back(name);
+    }
   }
-  if( hillsfname_.size()!=getNumberOfArguments() ) {
+  if( hillsfname_.size()!=pf_n_ ) {
     error("number of FILE arguments does not match number of HILLS files");
   }
 
@@ -448,6 +536,7 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
     height0_=(kbt_*(biasf_-1.0))/tau*getTimeStep()*stride_;
   }
 
+
   // Multiple walkers
   parse("WALKERS_N",mw_n_);
   parse("WALKERS_ID",mw_id_);
@@ -466,7 +555,10 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
     error("frequency with which to output grid not specified use GRID_WSTRIDE");
   }
   if(gridfilenames_.size()==0 && wgridstride_ > 0) {
-    for(unsigned i=0; i<getNumberOfArguments(); i++) gridfilenames_.push_back("GRID."+getPntrToArgument(i)->getName());
+    for(unsigned i=0; i<pf_n_; i++) {
+      std::string name = do_pf_ ? "GRID.PF"+std::to_string(i) : "GRID."+getPntrToArgument(i)->getName();
+      gridfilenames_.push_back(name);
+    }
   }
   if(gridfilenames_.size() > 0 && hillsfname_.size() > 0 && gridfilenames_.size() != hillsfname_.size())
     error("number of GRID_WFILES arguments does not match number of HILLS files");
@@ -476,18 +568,18 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   parseVector("GRID_RFILES",gridreadfilenames_);
 
   // Grid Stuff
-  std::vector<std::string> gmin(getNumberOfArguments());
+  std::vector<std::string> gmin(pf_n_);
   parseVector("GRID_MIN",gmin);
-  if(gmin.size()!=getNumberOfArguments() && gmin.size()!=0) error("not enough values for GRID_MIN");
-  std::vector<std::string> gmax(getNumberOfArguments());
+  if(gmin.size()!=pf_n_ && gmin.size()!=0) error("not enough values for GRID_MIN");
+  std::vector<std::string> gmax(pf_n_);
   parseVector("GRID_MAX",gmax);
-  if(gmax.size()!=getNumberOfArguments() && gmax.size()!=0) error("not enough values for GRID_MAX");
-  std::vector<unsigned> gbin(getNumberOfArguments());
+  if(gmax.size()!=pf_n_ && gmax.size()!=0) error("not enough values for GRID_MAX");
+  std::vector<unsigned> gbin(pf_n_);
   std::vector<double>   gspacing;
   parseVector("GRID_BIN",gbin);
-  if(gbin.size()!=getNumberOfArguments() && gbin.size()!=0) error("not enough values for GRID_BIN");
+  if(gbin.size()!=pf_n_ && gbin.size()!=0) error("not enough values for GRID_BIN");
   parseVector("GRID_SPACING",gspacing);
-  if(gspacing.size()!=getNumberOfArguments() && gspacing.size()!=0) error("not enough values for GRID_SPACING");
+  if(gspacing.size()!=pf_n_ && gspacing.size()!=0) error("not enough values for GRID_SPACING");
   if(gmin.size()!=gmax.size()) error("GRID_MAX and GRID_MIN should be either present or absent");
   if(gspacing.size()!=0 && gmin.size()==0) error("If GRID_SPACING is present also GRID_MIN and GRID_MAX should be present");
   if(gbin.size()!=0     && gmin.size()==0) error("If GRID_BIN is present also GRID_MIN and GRID_MAX should be present");
@@ -495,14 +587,14 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
     if(gbin.size()==0 && gspacing.size()==0) {
       if(adaptive_==FlexibleBin::none) {
         log<<"  Binsize not specified, 1/5 of sigma will be be used\n";
-        plumed_assert(sigma0_.size()==getNumberOfArguments());
-        gspacing.resize(getNumberOfArguments());
+        plumed_assert(sigma0_.size()==pf_n_);
+        gspacing.resize(pf_n_);
         for(unsigned i=0; i<gspacing.size(); i++) gspacing[i]=0.2*sigma0_[i];
       } else {
         // with adaptive hills and grid a sigma min must be specified
         for(unsigned i=0; i<sigma0min_.size(); i++) if(sigma0min_[i]<=0) error("When using ADAPTIVE Gaussians on a grid SIGMA_MIN must be specified");
         log<<"  Binsize not specified, 1/5 of sigma_min will be be used\n";
-        gspacing.resize(getNumberOfArguments());
+        gspacing.resize(pf_n_);
         for(unsigned i=0; i<gspacing.size(); i++) gspacing[i]=0.2*sigma0min_[i];
       }
     } else if(gspacing.size()!=0 && gbin.size()==0) {
@@ -511,12 +603,12 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
       log<<"  You specified both GRID_BIN and GRID_SPACING\n";
       log<<"  The more conservative (highest) number of bins will be used for each variable\n";
     }
-    if(gbin.size()==0) gbin.assign(getNumberOfArguments(),1);
-    if(gspacing.size()!=0) for(unsigned i=0; i<getNumberOfArguments(); i++) {
+    if(gbin.size()==0) gbin.assign(pf_n_,1);
+    if(gspacing.size()!=0) for(unsigned i=0; i<pf_n_; i++) {
         double a,b;
         Tools::convert(gmin[i],a);
         Tools::convert(gmax[i],b);
-        unsigned n=((b-a)/gspacing[i])+1;
+        unsigned n=std::ceil(((b-a)/gspacing[i]));
         if(gbin[i]<n) gbin[i]=n;
       }
   }
@@ -530,16 +622,16 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   if(!grid_&&gridfilenames_.size() > 0) error("To write a grid you need first to define it!");
   if(!grid_&&gridreadfilenames_.size() > 0) error("To read a grid you need first to define it!");
 
-  doInt_.resize(getNumberOfArguments(),false);
+  doInt_.resize(pf_n_,false);
   // Interval keyword
   parseVector("INTERVAL_MIN",lowI_);
   parseVector("INTERVAL_MAX",uppI_);
   // various checks
   if(lowI_.size()!=uppI_.size()) error("both a lower and an upper limits must be provided with INTERVAL");
-  if(lowI_.size()!=0 && lowI_.size()!=getNumberOfArguments()) error("check number of argument of INTERVAL");
+  if(lowI_.size()!=0 && lowI_.size()!=pf_n_) error("check number of argument of INTERVAL");
   for(unsigned i=0; i<lowI_.size(); ++i) {
     if(uppI_[i]<lowI_[i]) error("The Upper limit must be greater than the Lower limit!");
-    if(getPntrToArgument(i)->isPeriodic()) warning("INTERVAL is not used for periodic variables");
+    if(pfhold_[i]->isPeriodic()) warning("INTERVAL is not used for periodic variables");
     else doInt_[i]=true;
   }
 
@@ -547,6 +639,7 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   parse("SELECTOR", selector_);
   if(selector_.length()>0) {
     do_select_ = true;
+    select_value_ = 0; // set defalt value or it might be not initialized if the user does not pass SELECTOR_ID
     parse("SELECTOR_ID", select_value_);
   }
 
@@ -622,7 +715,7 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   }
 
   // initializing vector of hills
-  hills_.resize(getNumberOfArguments());
+  hills_.resize(pf_n_);
 
   // restart from external grid
   bool restartedFromGrid=false;
@@ -630,11 +723,12 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   // initializing and checking grid
   if(grid_) {
     // check for mesh and sigma size
-    for(unsigned i=0; i<getNumberOfArguments(); i++) {
+    for(unsigned i=0; i<pf_n_; i++) {
       double a,b;
-      Tools::convert(gmin[i],a);
-      Tools::convert(gmax[i],b);
-      double mesh=(b-a)/((double)gbin[i]);
+      int family = pfs_[i]; // point to families instead of arguments
+      Tools::convert(gmin[family],a);
+      Tools::convert(gmax[family],b);
+      double mesh=(b-a)/((double)gbin[family]);
       if(adaptive_==FlexibleBin::none) {
         if(mesh>0.5*sigma0_[i]) log<<"  WARNING: Using a PBMETAD with a Grid Spacing larger than half of the Gaussians width can produce artifacts\n";
       } else {
@@ -642,9 +736,9 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
       }
     }
     std::string funcl=getLabel() + ".bias";
-    for(unsigned i=0; i<getNumberOfArguments(); ++i) {
+    for(unsigned i=0; i<pf_n_; ++i) {
       std::vector<Value*> args(1);
-      args[0] = getPntrToArgument(i);
+      args[0] = pfhold_[i];  //Use first argument in family for interactions.
       std::vector<std::string> gmin_t(1);
       std::vector<std::string> gmax_t(1);
       std::vector<unsigned>    gbin_t(1);
@@ -666,7 +760,7 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
         if(BiasGrid_->getDimension() != args.size()) {
           error("mismatch between dimensionality of input grid and number of arguments");
         }
-        if(getPntrToArgument(i)->isPeriodic() != BiasGrid_->getIsPeriodic()[0]) {
+        if(pfhold_[i]->isPeriodic() != BiasGrid_->getIsPeriodic()[0]) {
           error("periodicity mismatch between arguments and input bias");
         }
         log.printf("  Restarting from %s:\n",gridreadfilenames_[i].c_str());
@@ -686,8 +780,10 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
   }
 
 
+
 // creating vector of ifile* for hills reading
 // open all files at the beginning and read Gaussians if restarting
+
   for(int j=0; j<mw_n_; ++j) {
     for(unsigned i=0; i<hillsfname_.size(); ++i) {
       unsigned k=j*hillsfname_.size()+i;
@@ -756,7 +852,7 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
     }
     ofile->setHeavyFlush();
     // output periodicities of variables
-    ofile->setupPrintValue( getPntrToArgument(i) );
+    ofile->setupPrintValue( pfhold_[i] );  //assuming cvs in the same family have the same periodicity and boundaries.
     // push back
     hillsOfiles_.emplace_back(std::move(ofile));
   }
@@ -792,7 +888,10 @@ PBMetaD::PBMetaD(const ActionOptions& ao):
                                    "Raiteri, Laio, Gervasio, Micheletti, and Parrinello, J. Phys. Chem. B 110, 3533 (2006)");
   if(adaptive_!=FlexibleBin::none) log<<plumed.cite(
                                           "Branduardi, Bussi, and Parrinello, J. Chem. Theory Comput. 8, 2247 (2012)");
+  if (do_pf_) log<<plumed.cite("Prakash, Fu, Bonomi, and Pfaendtner, J. Chem. Theory Comput. 14, 4985 (2018)");
   log<<"\n";
+
+
 }
 
 void PBMetaD::readGaussians(unsigned iarg, IFile *ifile)
@@ -802,33 +901,35 @@ void PBMetaD::readGaussians(unsigned iarg, IFile *ifile)
   double height;
   int nhills=0;
   bool multivariate=false;
+  int family=pfs_[iarg];
 
   std::vector<Value> tmpvalues;
-  tmpvalues.push_back( Value( this, getPntrToArgument(iarg)->getName(), false ) );
+  tmpvalues.push_back( Value( this, pfhold_[family]->getName(), false ) );
 
   while(scanOneHill(iarg,ifile,tmpvalues,center,sigma,height,multivariate)) {
     ;
     nhills++;
     if(welltemp_) {height*=(biasf_-1.0)/biasf_;}
-    addGaussian(iarg, Gaussian(center,sigma,height,multivariate));
+    addGaussian(family, Gaussian(center,sigma,height,multivariate));
   }
   log.printf("      %d Gaussians read\n",nhills);
 }
 
 void PBMetaD::writeGaussian(unsigned iarg, const Gaussian& hill, OFile *ofile)
 {
+  int family=pfs_[iarg];
   ofile->printField("time",getTimeStep()*getStep());
-  ofile->printField(getPntrToArgument(iarg),hill.center[0]);
+  ofile->printField(pfhold_[family],hill.center[0]);
 
   ofile->printField("kerneltype","stretched-gaussian");
   if(hill.multivariate) {
     ofile->printField("multivariate","true");
     double lower = std::sqrt(1./hill.sigma[0]);
-    ofile->printField("sigma_"+getPntrToArgument(iarg)->getName()+"_"+
-                      getPntrToArgument(iarg)->getName(),lower);
+    ofile->printField("sigma_"+pfhold_[family]->getName()+"_"+
+                      pfhold_[family]->getName(),lower);
   } else {
     ofile->printField("multivariate","false");
-    ofile->printField("sigma_"+getPntrToArgument(iarg)->getName(),hill.sigma[0]);
+    ofile->printField("sigma_"+pfhold_[family]->getName(),hill.sigma[0]);
   }
   double height=hill.height;
   if(welltemp_) height *= biasf_/(biasf_-1.0);
@@ -904,21 +1005,22 @@ std::vector<unsigned> PBMetaD::getGaussianSupport(unsigned iarg, const Gaussian&
 double PBMetaD::getBiasAndDerivatives(unsigned iarg, const std::vector<double>& cv, double* der)
 {
   double bias=0.0;
+  int family = pfs_[iarg];
   if(!grid_) {
     unsigned stride=comm.Get_size();
     unsigned rank=comm.Get_rank();
-    for(unsigned i=rank; i<hills_[iarg].size(); i+=stride) {
-      bias += evaluateGaussian(iarg,cv,hills_[iarg][i],der);
+    for(unsigned i=rank; i<hills_[family].size(); i+=stride) {
+      bias += evaluateGaussian(iarg,cv,hills_[family][i],der);
     }
     comm.Sum(bias);
     if(der) comm.Sum(der,1);
   } else {
     if(der) {
       std::vector<double> vder(1);
-      bias = BiasGrids_[iarg]->getValueAndDerivatives(cv,vder);
+      bias = BiasGrids_[family]->getValueAndDerivatives(cv,vder);
       der[0] = vder[0];
     } else {
-      bias = BiasGrids_[iarg]->getValue(cv);
+      bias = BiasGrids_[family]->getValue(cv);
     }
   }
 
@@ -994,7 +1096,7 @@ void PBMetaD::calculate()
   // set Forces - set them to zero if SELECTOR is active
   if(do_select_) current_value_ = static_cast<unsigned>(plumed.passMap[selector_]);
 
-  if(!do_select_ || (do_select_ && select_value_==current_value_)) {
+  if(!do_select_ || select_value_==current_value_) {
     for(unsigned i=0; i<getNumberOfArguments(); ++i) {
       const double f = - std::exp((-bias[i]+bmin)/kbt_) / (ene) * deriv[i];
       setOutputForce(i, f);
@@ -1029,7 +1131,7 @@ void PBMetaD::update()
     multivariate=false;
   }
 
-  if(nowAddAHill && (!do_select_ || (do_select_ && select_value_==current_value_))) {
+  if(nowAddAHill && (!do_select_ || select_value_==current_value_)) {
     // get all biases and heights
     std::vector<double> cv(getNumberOfArguments());
     std::vector<double> bias(getNumberOfArguments());
@@ -1040,8 +1142,10 @@ void PBMetaD::update()
     double norm = 0.0;
     double bmin = 1.0e+19;
     for(unsigned i=0; i<getNumberOfArguments(); ++i) {
-      if(adaptive_!=FlexibleBin::none) thissigma[i]=flexbin_[i].getInverseMatrix(i)[0];
-      else thissigma[i]=sigma0_[i];
+      int family=pfs_[i];
+      // get flex/sigmas for each family and assign them to this args sigma
+      if(adaptive_!=FlexibleBin::none) thissigma[i]=flexbin_[family].getInverseMatrix(i)[0];
+      else thissigma[i]=sigma0_[family];
       cv[i]     = getArgument(i);
       cv_tmp[0] = getArgument(i);
       bias[i] = getBiasAndDerivatives(i, cv_tmp);
@@ -1085,23 +1189,27 @@ void PBMetaD::update()
       // now add hills one by one
       for(unsigned j=0; j<mpi_nw_; ++j) {
         for(unsigned i=0; i<getNumberOfArguments(); ++i) {
+          // Add CVs of same family together and write to same file
+          int family = pfs_[i];
           cv_tmp[0]    = all_cv[j*cv.size()+i];
           double height_tmp = all_height[j*cv.size()+i];
           sigma_tmp[0] = all_sigma[j*cv.size()+i];
           Gaussian newhill = Gaussian(cv_tmp, sigma_tmp, height_tmp, multivariate);
-          addGaussian(i, newhill);
-          writeGaussian(i, newhill, hillsOfiles_[i].get());
+          addGaussian(family, newhill);
+          writeGaussian(i, newhill, hillsOfiles_[family].get());
         }
       }
       // just add your own hills
     } else {
       for(unsigned i=0; i<getNumberOfArguments(); ++i) {
+        // Add CVs of same family together and write to same file
+        int family = pfs_[i];
         cv_tmp[0] = cv[i];
         if(adaptive_!=FlexibleBin::none) sigma_tmp[0]=thissigma[i];
-        else sigma_tmp[0] = sigma0_[i];
+        else sigma_tmp[0] = sigma0_[family];
         Gaussian newhill = Gaussian(cv_tmp, sigma_tmp, height[i], multivariate);
-        addGaussian(i, newhill);
-        writeGaussian(i, newhill, hillsOfiles_[i].get());
+        addGaussian(family, newhill);
+        writeGaussian(i, newhill, hillsOfiles_[family].get());
       }
     }
   }
@@ -1153,13 +1261,14 @@ bool PBMetaD::scanOneHill(unsigned iarg, IFile *ifile, std::vector<Value> &tmpva
 {
   double dummy;
   multivariate=false;
+  Value* argPtr = pfhold_[pfs_[iarg]];
   if(ifile->scanField("time",dummy)) {
     ifile->scanField( &tmpvalues[0] );
-    if( tmpvalues[0].isPeriodic() && ! getPntrToArgument(iarg)->isPeriodic() ) {
+    if( tmpvalues[0].isPeriodic() && ! argPtr->isPeriodic() ) {
       error("in hills file periodicity for variable " + tmpvalues[0].getName() + " does not match periodicity in input");
     } else if( tmpvalues[0].isPeriodic() ) {
       std::string imin, imax; tmpvalues[0].getDomain( imin, imax );
-      std::string rmin, rmax; getPntrToArgument(iarg)->getDomain( rmin, rmax );
+      std::string rmin, rmax; argPtr->getDomain( rmin, rmax );
       if( imin!=rmin || imax!=rmax ) {
         error("in hills file periodicity for variable " + tmpvalues[0].getName() + " does not match periodicity in input");
       }
@@ -1180,11 +1289,11 @@ bool PBMetaD::scanOneHill(unsigned iarg, IFile *ifile, std::vector<Value> &tmpva
     else if(sss=="false") multivariate=false;
     else plumed_merror("cannot parse multivariate = "+ sss);
     if(multivariate) {
-      ifile->scanField("sigma_"+getPntrToArgument(iarg)->getName()+"_"+
-                       getPntrToArgument(iarg)->getName(),sigma[0]);
+      ifile->scanField("sigma_"+argPtr->getName()+"_"+
+                       argPtr->getName(),sigma[0]);
       sigma[0] = 1./(sigma[0]*sigma[0]);
     } else {
-      ifile->scanField("sigma_"+getPntrToArgument(iarg)->getName(),sigma[0]);
+      ifile->scanField("sigma_"+argPtr->getName(),sigma[0]);
     }
     ifile->scanField("height",height);
     ifile->scanField("biasf",dummy);
