@@ -91,7 +91,8 @@ Action::Action(const ActionOptions&ao):
   if ( keywords.exists("RESTART") ) {
     std::string srestart="AUTO";
     parse("RESTART",srestart);
-    if(srestart=="YES") restart=true;
+    if( plumed.parseOnlyMode() ) restart=false;
+    else if(srestart=="YES") restart=true;
     else if(srestart=="NO")  restart=false;
     else if(srestart=="AUTO") {
       // do nothing, this is the default
@@ -197,10 +198,6 @@ void Action::clearDependencies() {
   after.clear();
 }
 
-std::string Action::getDocumentation()const {
-  return std::string("UNDOCUMENTED ACTION");
-}
-
 void Action::checkRead() {
   if(!line.empty()) {
     std::string msg="cannot understand the following words from the input line : ";
@@ -212,7 +209,7 @@ void Action::checkRead() {
   }
 }
 
-long int Action::getStep()const {
+long long int Action::getStep()const {
   return plumed.getStep();
 }
 
