@@ -99,6 +99,8 @@ private:
 
   bool doCheckPoint;
 
+/// The set of default arguments that we are using
+  std::string defaults;
 public:
 
 /// Reference to main plumed object
@@ -114,7 +116,7 @@ public:
   void clearDependencies();
 
 /// Return the present timestep
-  long int getStep()const;
+  long long int getStep()const;
 
 /// Return the present time
   double getTime()const;
@@ -228,8 +230,6 @@ public:
 /// Tell to the Action to flush open files
   void fflush();
 
-  virtual std::string getDocumentation()const;
-
 /// Returns the label
   const std::string & getLabel()const;
 
@@ -287,6 +287,9 @@ public:
 
 /// Cite a paper see PlumedMain::cite
   std::string cite(const std::string&s);
+
+/// Get the defaults
+  std::string getDefaultString() const ;
 };
 
 /////////////////////
@@ -304,11 +307,6 @@ const std::string & Action::getName()const {
 
 template<class T>
 void Action::parse(const std::string&key,T&t) {
-//  if(!Tools::parse(line,key,t)){
-//    log.printf("ERROR parsing keyword %s\n",key.c_str());
-//    log.printf("%s\n",getDocumentation().c_str());
-//    this->exit(1);
-//  }
   // Check keyword has been registered
   plumed_massert(keywords.exists(key),"keyword " + key + " has not been registered");
 
@@ -324,6 +322,7 @@ void Action::parse(const std::string&key,T&t) {
       if( def.length()==0 || !Tools::convertNoexcept(def,t) ) {
         plumed_error() <<"ERROR in action "<<name<<" with label "<<label<<" : keyword "<<key<<" has weird default value";
       }
+      defaults += " " + key + "=" + def;
     } else if( keywords.style(key,"compulsory") ) {
       error("keyword " + key + " is compulsory for this action");
     }
@@ -343,12 +342,6 @@ bool Action::parseNumbered(const std::string&key, const int no, T&t) {
 
 template<class T>
 void Action::parseVector(const std::string&key,std::vector<T>&t) {
-//  if(!Tools::parseVector(line,key,t)){
-//    log.printf("ERROR parsing keyword %s\n",key.c_str());
-//    log.printf("%s\n",getDocumentation().c_str());
-//    this->exit(1);
-//  }
-
   // Check keyword has been registered
   plumed_massert(keywords.exists(key), "keyword " + key + " has not been registered");
   unsigned size=t.size(); bool skipcheck=false;
@@ -373,8 +366,10 @@ void Action::parseVector(const std::string&key,std::vector<T>&t) {
       if( def.length()==0 || !Tools::convertNoexcept(def,val) ) {
         plumed_error() <<"ERROR in action "<<name<<" with label "<<label<<" : keyword "<<key<<" has weird default value";
       } else {
-        if(t.size()>0) for(unsigned i=0; i<t.size(); ++i) t[i]=val;
-        else t.push_back(val);
+        if(t.size()>0) {
+          for(unsigned i=0; i<t.size(); ++i) t[i]=val;
+          defaults += " " + key + "=" + def; for(unsigned i=1; i<t.size(); ++i) defaults += "," + def;
+        } else { t.push_back(val); defaults += " " + key + "=" + def; }
       }
     } else if( keywords.style(key,"compulsory") ) {
       error("keyword " + key + " is compulsory for this action");
@@ -425,6 +420,11 @@ bool Action::getRestart()const {
   return restart;
 }
 
+inline
+std::string Action::getDefaultString() const {
+  return defaults;
+}
+
 }
 #endif
 
