@@ -32,11 +32,12 @@ void ActionWithValue::registerKeywords(Keywords& keys) {
                                  "below.  These quantities can be referenced elsewhere in the input by using this Action's "
                                  "label followed by a dot and the name of the quantity required from the list below.");
   keys.addFlag("NUMERICAL_DERIVATIVES", false, "calculate the derivatives for these quantities numerically");
+  keys.add("hidden","HAS_VALUES","this is used in json output to determine those actions that have values");
 }
 
 void ActionWithValue::noAnalyticalDerivatives(Keywords& keys) {
   keys.remove("NUMERICAL_DERIVATIVES");
-  keys.addFlag("NUMERICAL_DERIVATIVES",true,"analytical derivatives are not implemented for this keyword so numerical derivatives are always used");
+  keys.addFlag("NUMERICAL_DERIVATIVES",false,"analytical derivatives are not implemented for this keyword so numerical derivatives are always used");
 }
 
 void ActionWithValue::componentsAreNotOptional(Keywords& keys) {
