@@ -288,7 +288,7 @@ void EDS::registerKeywords(Keywords &keys)
            "CENTER_ARG is for calculated centers, e.g. from a CV or analysis. ");
 
   keys.add("optional", "PERIOD", "Steps over which to adjust bias for adaptive or ramping");
-  keys.add("compulsory", "RANGE", "25.0", "The (starting) maximum increase in coupling constant per PERIOD (in \\f$k_B T\\f$/[BIAS_SCALE unit]) for each CV based");
+  keys.add("compulsory", "RANGE", "25.0", "The (starting) maximum increase in coupling constant per PERIOD (in \\f$k_B T\\f$/[BIAS_SCALE unit]) for each CV biased");
   keys.add("compulsory", "SEED", "0", "Seed for random order of changing bias");
   keys.add("compulsory", "INIT", "0", "Starting value for coupling constant");
   keys.add("compulsory", "FIXED", "0", "Fixed target values for coupling constant. Non-adaptive.");
@@ -301,8 +301,7 @@ void EDS::registerKeywords(Keywords &keys)
   keys.add("optional", "VIRIAL", "Add an update penalty for having non-zero virial contributions. Only makes sense with multiple correlated CVs.");
   keys.add("optional", "LOGWEIGHTS", "Add weights to use for computing statistics. For example, if biasing with metadynamics.");
   keys.addFlag("LM", false, "Use Levenberg-Marquadt algorithm along with simultaneous keyword. Otherwise use gradient descent.");
-  keys.addFlag("LM_MIXING", "1", "Initial mixing parameter when using Levenberg-Marquadt minimization.");
-
+  keys.add("compulsory", "LM_MIXING", "1", "Initial mixing parameter when using Levenberg-Marquadt minimization.");
   keys.add("optional", "RESTART_FMT", "the format that should be used to output real numbers in EDS restarts");
   keys.add("optional", "OUT_RESTART", "Output file for all information needed to continue EDS simulation. "
            "If you have the RESTART directive set (global or for EDS), this file will be appended to. "
