@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2022 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -180,7 +180,9 @@ PLUMED_REGISTER_ACTION(Custom,"CUSTOM")
 
 //+PLUMEDOC FUNCTION MATHEVAL
 /*
-An alias to the \ref CUSTOM function.
+An alias to the CUSTOM function that can also be used to calaculate combinations of variables using a custom expression.
+
+Documentation for this action is identical to that for \ref CUSTOM
 
 This alias is kept in order to maintain compatibility with previous PLUMED versions.
 However, notice that as of PLUMED 2.5 the libmatheval library is not linked anymore,
