@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2016-2022 The plumed team
+   Copyright (c) 2016-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -29,7 +29,7 @@ namespace isdb {
 
 //+PLUMEDOC ISDB_COLVAR JCOUPLING
 /*
-Calculates \f$^3J\f$ coupling constants for a dihedral angle.
+Calculates 3J coupling constants for a dihedral angle.
 
 The J-coupling between two atoms is given by the Karplus relation:
 
