@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2022 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -24,9 +24,18 @@
 #include "AtomNumber.h"
 #include <cstdlib>
 #include <cstring>
+#include <cstdio>
 
 namespace PLMD {
 
+bool Communicator::plumedHasMPI() {
+#ifdef __PLUMED_HAS_MPI
+  return true;
+#else
+  return false;
+#endif
+}
+
 Communicator::Communicator()
 #ifdef __PLUMED_HAS_MPI
   : communicator(MPI_COMM_SELF)
@@ -108,10 +117,9 @@ void Communicator::Abort(int errorcode) {
   if(initialized()) {
     MPI_Abort(communicator,errorcode);
   }
-  std::exit(errorcode);
-#else
-  std::exit(errorcode);
 #endif
+  std::fprintf(stderr,"aborting with error code %d\n",errorcode);
+  std::abort();
 }
 
 void Communicator::Bcast(Data data,int root) {
