@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2022 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -25,6 +25,7 @@
 #include "OpenMP.h"
 #include <vector>
 #include <limits>
+#include <algorithm>
 
 #define PI 3.14159265358979323846
 
@@ -36,7 +37,7 @@ Functions that measure whether values are less than a certain quantity.
 
 Switching functions \f$s(r)\f$ take a minimum of one input parameter \f$r_0\f$.
 For \f$r \le d_0 \quad s(r)=1.0\f$ while for \f$r > d_0\f$ the function decays smoothly to 0.
-The various switching functions available in plumed differ in terms of how this decay is performed.
+The various switching functions available in PLUMED differ in terms of how this decay is performed.
 
 Where there is an accepted convention in the literature (e.g. \ref COORDINATION) on the form of the
 switching function we use the convention as the default.  However, the flexibility to use different
@@ -47,7 +48,7 @@ takes an input with the following form:
 KEYWORD={TYPE <list of parameters>}
 \endverbatim
 
-The following table contains a list of the various switching functions that are available in plumed 2
+The following table contains a list of the various switching functions that are available in PLUMED 2
 together with an example input.
 
 <table align=center frame=void width=95%% cellpadding=5%%>
@@ -110,10 +111,11 @@ s(r) = 1 - \tanh\left( \frac{ r - d_0 }{ r_0 } \right)
 </td> <td> </td>
 </tr> <tr>
 <td> COSINUS </td> <td>
-\f$
-s(r) &= 1  & if r<=d0
-s(r) &= 0.5 \left( \cos ( \frac{ r - d_0 }{ r_0 } * PI ) + 1 \right) & if d0<r<=d0+r0
-s(r) &= 0  & if r> d0+r0
+\f$s(r) =\left\{\begin{array}{ll}
+   1                                                           & \mathrm{if } r \leq d_0 \\
+   0.5 \left( \cos ( \frac{ r - d_0 }{ r_0 } \pi ) + 1 \right) & \mathrm{if } d_0 < r\leq d_0 + r_0 \\
+   0                                                           & \mathrm{if } r < d_0 + r_0
+  \end{array}\right.
 \f$
 </td> <td>
 {COSINUS R_0=\f$r_0\f$ D_0=\f$d_0\f$}
@@ -268,17 +270,22 @@ void SwitchingFunction::set(const std::string & definition,std::string& errormsg
     for(auto & e : expression) e=pe.createCompiledExpression();
     lepton_ref.resize(expression.size());
     for(unsigned t=0; t<lepton_ref.size(); t++) {
-      try {
-        lepton_ref[t]=&const_cast<lepton::CompiledExpression*>(&expression[t])->getVariableReference("x");
-      } catch(const PLMD::lepton::Exception& exc) {
-        try {
-          lepton_ref[t]=&const_cast<lepton::CompiledExpression*>(&expression[t])->getVariableReference("x2");
-          leptonx2=true;
-        } catch(const PLMD::lepton::Exception& exc) {
-// this is necessary since in some cases lepton things a variable is not present even though it is present
+      auto vars=expression[t].getVariables();
+      bool found_x=std::find(vars.begin(),vars.end(),"x")!=vars.end();
+      bool found_x2=std::find(vars.begin(),vars.end(),"x2")!=vars.end();
+      if (vars.size()==0) {
+// this is necessary since in some cases lepton thinks a variable is not present even though it is present
 // e.g. func=0*x
-          lepton_ref[t]=nullptr;
-        }
+        lepton_ref[t]=nullptr;
+      } else if(vars.size()==1 && found_x) {
+        lepton_ref[t]=&const_cast<lepton::CompiledExpression*>(&expression[t])->getVariableReference("x");
+      } else if(vars.size()==1 && found_x2) {
+        lepton_ref[t]=&const_cast<lepton::CompiledExpression*>(&expression[t])->getVariableReference("x2");
+        leptonx2=true;
+      } else if(vars.size()==2 && found_x && found_x2) {
+        plumed_error() << "Cannot use simultaneously x and x2 argument in switching function: "<<func;
+      } else {
+        plumed_error() << "Something wrong in the arguments for switching function: "<<func;
       }
     }
     std::string arg="x";
@@ -364,9 +371,12 @@ double SwitchingFunction::do_rational(double rdist,double&dfunc,int nn,int mm)co
     dfunc = -nn*rNdist*iden*iden;
     result = iden;
   } else {
-    if(rdist>(1.-100.0*epsilon) && rdist<(1+100.0*epsilon)) {
-      result=nn/mm;
-      dfunc=0.5*nn*(nn-mm)/mm;
+    if(rdist>(1.-5.0e10*epsilon) && rdist<(1+5.0e10*epsilon)) {
+      const double secDev = ((nn * (mm * mm - 3.0* mm * (-1 + nn ) + nn *(-3 + 2* nn )))/(6.0* mm ));
+      const double x =(rdist-1.0);
+      dfunc=0.5*nn*double(nn-mm)/mm;
+      result = double(nn)/mm+ x * ( dfunc + 0.5 * x * secDev);
+      dfunc  = dfunc + x * secDev;
     } else {
       double rNdist=Tools::fastpow(rdist,nn-1);
       double rMdist=Tools::fastpow(rdist,mm-1);
@@ -450,7 +460,7 @@ double SwitchingFunction::calculate(double distance,double&dfunc)const {
       double exprdist=std::exp(rdist2);
       double exprmdist=1.0/exprdist;
       result=1./(1.+exprdist);
-      dfunc=-1.0/(exprmdist+1.0)/(1.+exprdist);
+      dfunc=-beta/(exprmdist+1.0)/(1.+exprdist)/invr0;
     } else if(type==gaussian) {
       result=std::exp(-0.5*rdist*rdist);
       dfunc=-rdist*result;
@@ -485,8 +495,10 @@ double SwitchingFunction::calculate(double distance,double&dfunc)const {
       result=expression[t].evaluate();
       dfunc=expression_deriv[t].evaluate();
     } else plumed_merror("Unknown switching function type");
-// this is for the chain rule:
+// this is for the chain rule (derivative of rdist):
     dfunc*=invr0;
+// for any future switching functions, be aware that multiplying invr0 is only correct for functions of rdist = (r-d0)/r0.
+
 // this is because calculate() sets dfunc to the derivative divided times the distance.
 // (I think this is misleading and I would like to modify it - GB)
     dfunc/=distance;
